==> speech-analytic-testing_2.2.2_database.tar.gz: database/mssql/procedures/GetI6InteractionAudios.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6InteractionAudios] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL
) AS 
BEGIN
	-- DECLARAMOS VARIABLES PARA ALMACENAR LAS CANTIDADES DE REGISTROS
	DECLARE @AUDIO_RECORDS INT = 0
	DECLARE @INTERACION_EVALUATION_PLAN_RECORDS INT = 0

	SELECT @AUDIO_RECORDS = COUNT(*)
		FROM [dbo].[Audio] A (NOLOCK)
		WHERE A.[VCC] = @VCC
			AND A.[ID] = @InteractionId

	SELECT @INTERACION_EVALUATION_PLAN_RECORDS = COUNT(DISTINCT CONCAT(IEP.[IdInteraction], '_', IEP.[InteractionSection], '_', IEP.[InteractionPart]))
		FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		WHERE IEP.[Instance] = @VCC	
			AND IEP.[IdInteraction] = @InteractionId

	IF @AUDIO_RECORDS >= @INTERACION_EVALUATION_PLAN_RECORDS
	BEGIN

		-- BUSCAMOS LOS AUDIOS DE LA INTERACCION
		SELECT [ID]									'id',
				[Section]							'section',
				[Part]								'part',
				[Agent]								'agent',
				[Format]							'format'
			FROM [dbo].[Audio] A (NOLOCK)
			WHERE A.[VCC] = @VCC
				AND A.[ID] = @InteractionId
			ORDER BY A.[Section] ASC,  A.[Part] ASC
	END
	ELSE
	BEGIN
		SELECT [IdInteraction]						'id',
				[InteractionSection]				'section',
				[InteractionPart]					'part',
				[IdAgent]							'agent',
				[InteractionFormat]					'format'
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @VCC	
				AND IEP.[IdInteraction] = @InteractionId
			ORDER by IEP.[InteractionSection] ASC, IEP.[InteractionPart] ASC
	END
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetI6InteractionAudios.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6InteractionAudios] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL
) AS 
BEGIN
	-- DECLARAMOS VARIABLES PARA ALMACENAR LAS CANTIDADES DE REGISTROS
	DECLARE @AUDIO_RECORDS INT = 0
	DECLARE @INTERACION_EVALUATION_PLAN_RECORDS INT = 0

	SELECT @AUDIO_RECORDS = COUNT(*)
		FROM [dbo].[Audio] A (NOLOCK)
		WHERE A.[VCC] = @VCC
			AND A.[ID] = @InteractionId

	SELECT @INTERACION_EVALUATION_PLAN_RECORDS = COUNT(DISTINCT CONCAT(IEP.[IdInteraction], '_', IEP.[InteractionSection], '_', IEP.[InteractionPart]))
		FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		WHERE IEP.[Instance] = @VCC	
			AND IEP.[IdInteraction] = @InteractionId

	IF @AUDIO_RECORDS >= @INTERACION_EVALUATION_PLAN_RECORDS
	BEGIN

		-- BUSCAMOS LOS AUDIOS DE LA INTERACCION
		SELECT [ID]									'id',
				[Section]							'section',
				[Part]								'part',
				[Agent]								'agentId',
				[Format]							'format'
			FROM [dbo].[Audio] A (NOLOCK)
			WHERE A.[VCC] = @VCC
				AND A.[ID] = @InteractionId
			ORDER BY A.[Section] ASC,  A.[Part] ASC
	END
	ELSE
	BEGIN
		SELECT [IdInteraction]						'id',
				[InteractionSection]				'section',
				[InteractionPart]					'part',
				[IdAgent]							'agentId',
				[InteractionFormat]					'format'
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @VCC	
				AND IEP.[IdInteraction] = @InteractionId
			ORDER by IEP.[InteractionSection] ASC, IEP.[InteractionPart] ASC
	END
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
